==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/usermanager/lang/pt-br/lang.php <==
<?php
/**
 * Portuguese language file
 *
 * @author Frederico Gonçalves Guimarães <frederico@teia.bio.br>
 * @author Felipe Castro <fefcas@gmail.com>
 */
$lang['menu']                  = 'Gerenciamento de Usuários';
$lang['noauth']                = '(o gerenciamento de usuários não está disponível)';
$lang['nosupport']             = '(o gerenciamento de usuários não é suportado)';
$lang['badauth']               = 'mecanismo de autenticação inválido';
$lang['user_id']               = 'Usuário';
$lang['user_pass']             = 'Senha';
$lang['user_name']             = 'Nome real';
$lang['user_mail']             = 'Emeil';
$lang['user_groups']           = 'Grupos';
$lang['field']                 = 'Campo';
$lang['value']                 = 'Valor';
$lang['add']                   = 'Adicionar';
$lang['delete']                = 'Excluir';
$lang['delete_selected']       = 'Excluir a seleção';
$lang['edit']                  = 'Editar';
$lang['edit_prompt']           = 'Editar esse usuário';
$lang['modify']                = 'Salvar alterações';
$lang['search']                = 'Procurar';
$lang['search_prompt']         = 'Executar a procura';
$lang['clear']                 = 'Limpar o filtro de procura';
$lang['filter']                = 'Filtro';
$lang['summary']               = 'Exibindo usuários %1$d-%2$d de %3$d encontrados. %4$d usuários no total.';
$lang['nonefound']             = 'Nenhum usuário encontrado. %d usuários no total.';
$lang['delete_ok']             = '%d usuários excluídos';
$lang['delete_fail']           = 'Erro na exclusão de %d usuários';
$lang['update_ok']             = 'Usuário atualizado com sucesso';
$lang['update_fail']           = 'A atualização do usuário falhou';
$lang['update_exists']         = 'Não foi possível mudar o nome do usuário. O nome especificado (%s) já existe (as outras mudanças serão aplicadas).';
$lang['start']                 = 'primeira';
$lang['prev']                  = 'anterior';
$lang['next']                  = 'próxima';
$lang['last']                  = 'última';
$lang['edit_usermissing']      = 'O usuário selecionado não foi encontrado, ele foi excluído ou o seu nome modificado.';
$lang['user_notify']           = 'Notificar o usuário';
$lang['note_notify']           = 'Emeils de notificação são enviados apenas se o usuário forneceu uma senha.';
$lang['note_group']            = 'Novos usuários serão adicionados ao grupo padrão (%s), caso nenhum grupo seja especificado.';
$lang['add_ok']                = 'O usuário foi adicionado com sucesso';
$lang['add_fail']              = 'O usuário não foi adicionado';
$lang['notify_ok']             = 'O emeil de notificação foi enviado';
$lang['notify_fail']           = 'Não foi possível enviar o emeil de notificação';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/usermanager/lang/pt-br/lang.php <==
<?php
/**
 * Portuguese language file
 *
 * @author Frederico Gonçalves Guimarães <frederico@teia.bio.br>
 * @author Felipe Castro <fefcas@gmail.com>
 * @author Lucien Raven <lucienraven@yahoo.com.br>
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Flávio Veras <flaviove@gmail.com>
 * @author Jeferson Propheta <jeferson.propheta@gmail.com>
 * @author jair.henrique@gmail.com
 * @author Luis Dantas <luis@dantas.com>
 * @author Frederico Guimarães <frederico@teia.bio.br>
 */
$lang['menu']                  = 'Gerenciamento de Usuários';
$lang['noauth']                = '(o gerenciamento de usuários não está disponível)';
$lang['nosupport']             = '(o gerenciamento de usuários não é suportado)';
$lang['badauth']               = 'mecanismo de autenticação inválido';
$lang['user_id']               = 'Usuário';
$lang['user_pass']             = 'Senha';
$lang['user_name']             = 'Nome real';
$lang['user_mail']             = 'E-mail';
$lang['user_groups']           = 'Grupos';
$lang['field']                 = 'Campo';
$lang['value']                 = 'Valor';
$lang['add']                   = 'Adicionar';
$lang['delete']                = 'Excluir';
$lang['delete_selected']       = 'Excluir a seleção';
$lang['edit']                  = 'Editar';
$lang['edit_prompt']           = 'Editar esse usuário';
$lang['modify']                = 'Salvar as alterações';
$lang['search']                = 'Pesquisar';
$lang['search_prompt']         = 'Executar a pesquisa';
$lang['clear']                 = 'Limpar o filtro de pesquisa';
$lang['filter']                = 'Filtro';
$lang['summary']               = 'Exibindo usuários %1$d-%2$d de %3$d encontrados. %4$d usuários no total.';
$lang['nonefound']             = 'Nenhum usuário encontrado. %d usuários no total.';
$lang['delete_ok']             = '%d usuários excluídos';
$lang['delete_fail']           = 'Erro na exclusão de %d usuários.';
$lang['update_ok']             = 'Usuário atualizado com sucesso';
$lang['update_fail']           = 'Não foi possível atualizar o usuário';
$lang['update_exists']         = 'Não foi possível mudar o nome do usuário. O nome especificado (%s) já existe (as outras mudanças serão aplicadas).';
$lang['start']                 = 'primeira';
$lang['prev']                  = 'anterior';
$lang['next']                  = 'próxima';
$lang['last']                  = 'última';
$lang['edit_usermissing']      = 'O usuário selecionado não foi encontrado, ele foi excluído ou teve o seu nome modificado.';
$lang['user_notify']           = 'Notificar o usuário';
$lang['note_notify']           = 'E-mails de notificação são enviados apenas se o usuário digitar uma nova senha.';
$lang['note_group']            = 'Novos usuários serão adicionados ao grupo padrão (%s), caso nenhum grupo seja especificado.';
$lang['note_pass']             = 'A senha será gerada automaticamente se o campo for deixado em branco e a notificação de usuário estiver habilitada.';
$lang['add_ok']                = 'O usuário foi adicionado com sucesso';
$lang['add_fail']              = 'O usuário não foi adicionado';
$lang['notify_ok']             = 'O e-mail de notificação foi enviado';
$lang['notify_fail']           = 'Não foi possível enviar o e-mail de notificação';
